ids_list_series_topics: List Available Series-Topic combinations from the World Bank International
Debt Statistics API
Description
This function returns a tibble with available series-topic combinations from
the World BankInternational Debt Statistics (IDS) API. Each row provides a
mapping from series to topic, with the possibility of multiple topic per
series.
Usage
ids_list_series_topics()
Arguments
Value
A tibble containing the available series and their topics:
series_id
The unique identifier for the series (e.g.,
"BM.GSR.TOTL.CD").