powered by
This function retrieves a tibble with metadata for series available via bulk download of the World Bank International Debt Statistics (IDS).
ids_bulk_series()
A tibble containing the available series and their metadata:
The unique identifier for the series (e.g., "BN.CAB.XOKA.CD").
The name of the series (e.g., "Current account balance (current US$)").
The ID of the data source providing the indicator.
The name or description of the source of the indicator data.
Additional notes or descriptions about the data source.
The organization responsible for the data source.
# \donttest{ ids_bulk_series() # }
Run the code above in your browser using DataLab